@@ -1,23 +1,31 @@
+from __future__ import annotations
+
 import math
 import sys
 import threading
+from collections.abc import Awaitable, Callable, Generator
 from contextlib import contextmanager
 from importlib import import_module
-from typing import Any, Callable, Coroutine, Dict, Generator, Optional, Tuple, Type, TypeVar
+from typing import TYPE_CHECKING, Any, TypeVar
 
 import sniffio
 
+if TYPE_CHECKING:
+    from ..abc import AsyncBackend
+
 # This must be updated when new backends are introduced
-from ._compat import DeprecatedAwaitableFloat
+BACKENDS = "asyncio", "trio"
 
-BACKENDS = 'asyncio', 'trio'
-
-T_Retval = TypeVar('T_Retval')
+T_Retval = TypeVar("T_Retval")
 threadlocals = threading.local()
 
 
-def run(func: Callable[..., Coroutine[Any, Any, T_Retval]], *args: object,
-        backend: str = 'asyncio', backend_options: Optional[Dict[str, Any]] = None) -> T_Retval:
+def run(
+    func: Callable[..., Awaitable[T_Retval]],
+    *args: object,
+    backend: str = "asyncio",
+    backend_options: dict[str, Any] | None = None,
+) -> T_Retval:
     """
     Run the given coroutine function in an asynchronous event loop.
 
@@ -25,12 +33,13 @@ def run(func: Callable[..., Coroutine[Any, Any, T_Retval]], *args: object,
 
     :param func: a coroutine function
     :param args: positional arguments to ``func``
-    :param backend: name of the asynchronous event loop implementation – currently either
-        ``asyncio`` or ``trio``
-    :param backend_options: keyword arguments to call the backend ``run()`` implementation with
-        (documented :ref:`here <backend options>`)
+    :param backend: name of the asynchronous event loop implementation – currently
+        either ``asyncio`` or ``trio``
+    :param backend_options: keyword arguments to call the backend ``run()``
+        implementation with (documented :ref:`here <backend options>`)
     :return: the return value of the coroutine function
-    :raises RuntimeError: if an asynchronous event loop is already running in this thread
+    :raises RuntimeError: if an asynchronous event loop is already running in this
+        thread
     :raises LookupError: if the named backend is not found
 
     """
@@ -39,21 +48,22 @@ def run(func: Callable[..., Coroutine[Any, Any, T_Retval]], *args: object,
     except sniffio.AsyncLibraryNotFoundError:
         pass
     else:
-        raise RuntimeError(f'Already running {asynclib_name} in this thread')
+        raise RuntimeError(f"Already running {asynclib_name} in this thread")
 
     try:
-        asynclib = import_module(f'..._backends._{backend}', package=__name__)
+        async_backend = get_async_backend(backend)
     except ImportError as exc:
-        raise LookupError(f'No such backend: {backend}') from exc
+        raise LookupError(f"No such backend: {backend}") from exc
 
     token = None
     if sniffio.current_async_library_cvar.get(None) is None:
-        # Since we're in control of the event loop, we can cache the name of the async library
+        # Since we're in control of the event loop, we can cache the name of the async
+        # library
         token = sniffio.current_async_library_cvar.set(backend)
 
     try:
         backend_options = backend_options or {}
-        return asynclib.run(func, *args, **backend_options)  # type: ignore
+        return async_backend.run(func, args, {}, backend_options)
     finally:
         if token:
             sniffio.current_async_library_cvar.reset(token)
@@ -66,7 +76,7 @@ async def sleep(delay: float) -> None:
     :param delay: the duration, in seconds
 
     """
-    return await get_asynclib().sleep(delay)
+    return await get_async_backend().sleep(delay)
 
 
 async def sleep_forever() -> None:
@@ -85,8 +95,8 @@ async def sleep_until(deadline: float) -> None:
     """
     Pause the current task until the given time.
 
-    :param deadline: the absolute time to wake up at (according to the internal monotonic clock of
-        the event loop)
+    :param deadline: the absolute time to wake up at (according to the internal
+        monotonic clock of the event loop)
 
     .. versionadded:: 3.1
 
@@ -95,46 +105,52 @@ async def sleep_until(deadline: float) -> None:
     await sleep(max(deadline - now, 0))
 
 
-def current_time() -> DeprecatedAwaitableFloat:
+def current_time() -> float:
     """
     Return the current value of the event loop's internal clock.
 
     :return: the clock value (seconds)
 
     """
-    return DeprecatedAwaitableFloat(get_asynclib().current_time(), current_time)
+    return get_async_backend().current_time()
 
 
-def get_all_backends() -> Tuple[str, ...]:
+def get_all_backends() -> tuple[str, ...]:
     """Return a tuple of the names of all built-in backends."""
     return BACKENDS
 
 
-def get_cancelled_exc_class() -> Type[BaseException]:
+def get_cancelled_exc_class() -> type[BaseException]:
     """Return the current async library's cancellation exception class."""
-    return get_asynclib().CancelledError
+    return get_async_backend().cancelled_exception_class()
 
 
 #
 # Private API
 #
 
+
 @contextmanager
-def claim_worker_thread(backend: str) -> Generator[Any, None, None]:
-    module = sys.modules['anyio._backends._' + backend]
-    threadlocals.current_async_module = module
+def claim_worker_thread(
+    backend_class: type[AsyncBackend], token: object
+) -> Generator[Any, None, None]:
+    threadlocals.current_async_backend = backend_class
+    threadlocals.current_token = token
     try:
         yield
     finally:
-        del threadlocals.current_async_module
+        del threadlocals.current_async_backend
+        del threadlocals.current_token
 
 
-def get_asynclib(asynclib_name: Optional[str] = None) -> Any:
+def get_async_backend(asynclib_name: str | None = None) -> AsyncBackend:
     if asynclib_name is None:
         asynclib_name = sniffio.current_async_library()
 
-    modulename = 'anyio._backends._' + asynclib_name
+    modulename = "anyio._backends._" + asynclib_name
     try:
-        return sys.modules[modulename]
+        module = sys.modules[modulename]
     except KeyError:
-        return import_module(modulename)
+        module = import_module(modulename)
+
+    return getattr(module, "backend_class")
